==> pmml-model-gwt-1.5.12-sources.jar: org/dmg/pmml/bayesian_network/ContinuousDistribution.java <==

package org.dmg.pmml.bayesian_network;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlType(name = "", propOrder = {
    "extensions",
    "triangularDistributionForBN",
    "normalDistributionForBN",
    "lognormalDistributionForBN",
    "uniformDistributionForBN"
})
@Added((org.dmg.pmml.Version.PMML_4_3))
@JsonPropertyOrder({
    "extensions",
    "triangularDistributionForBN",
    "normalDistributionForBN",
    "lognormalDistributionForBN",
    "uniformDistributionForBN"
})
public class ContinuousDistribution
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<ContinuousDistribution>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "TriangularDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("TriangularDistributionForBN")
    private TriangularDistribution triangularDistributionForBN;
    @XmlElement(name = "NormalDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("NormalDistributionForBN")
    private NormalDistribution normalDistributionForBN;
    @XmlElement(name = "LognormalDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("LognormalDistributionForBN")
    private LognormalDistribution lognormalDistributionForBN;
    @XmlElement(name = "UniformDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("UniformDistributionForBN")
    private UniformDistribution uniformDistributionForBN;
    private final static long serialVersionUID = 67371267L;

    public ContinuousDistribution() {
    }

    @ValueConstructor
    public ContinuousDistribution(
        @org.jpmml.model.annotations.Property("triangularDistributionForBN")
        TriangularDistribution triangularDistributionForBN,
        @org.jpmml.model.annotations.Property("normalDistributionForBN")
        NormalDistribution normalDistributionForBN,
        @org.jpmml.model.annotations.Property("lognormalDistributionForBN")
        LognormalDistribution lognormalDistributionForBN,
        @org.jpmml.model.annotations.Property("uniformDistributionForBN")
        UniformDistribution uniformDistributionForBN) {
        this.triangularDistributionForBN = triangularDistributionForBN;
        this.normalDistributionForBN = normalDistributionForBN;
        this.lognormalDistributionForBN = lognormalDistributionForBN;
        this.uniformDistributionForBN = uniformDistributionForBN;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public ContinuousDistribution addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public TriangularDistribution getTriangularDistributionForBN() {
        return triangularDistributionForBN;
    }

    public ContinuousDistribution setTriangularDistributionForBN(
        @org.jpmml.model.annotations.Property("triangularDistributionForBN")
        TriangularDistribution triangularDistributionForBN) {
        this.triangularDistributionForBN = triangularDistributionForBN;
        return this;
    }

    public NormalDistribution getNormalDistributionForBN() {
        return normalDistributionForBN;
    }

    public ContinuousDistribution setNormalDistributionForBN(
        @org.jpmml.model.annotations.Property("normalDistributionForBN")
        NormalDistribution normalDistributionForBN) {
        this.normalDistributionForBN = normalDistributionForBN;
        return this;
    }

    public LognormalDistribution getLognormalDistributionForBN() {
        return lognormalDistributionForBN;
    }

    public ContinuousDistribution setLognormalDistributionForBN(
        @org.jpmml.model.annotations.Property("lognormalDistributionForBN")
        LognormalDistribution lognormalDistributionForBN) {
        this.lognormalDistributionForBN = lognormalDistributionForBN;
        return this;
    }

    public UniformDistribution getUniformDistributionForBN() {
        return uniformDistributionForBN;
    }

    public ContinuousDistribution setUniformDistributionForBN(
        @org.jpmml.model.annotations.Property("uniformDistributionForBN")
        UniformDistribution uniformDistributionForBN) {
        this.uniformDistributionForBN = uniformDistributionForBN;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTriangularDistributionForBN(), getNormalDistributionForBN(), getLognormalDistributionForBN(), getUniformDistributionForBN());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.0-sources.jar: org/dmg/pmml/bayesian_network/ContinuousDistribution.java <==

package org.dmg.pmml.bayesian_network;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlType(name = "", propOrder = {
    "extensions",
    "triangularDistributionForBN",
    "normalDistributionForBN",
    "lognormalDistributionForBN",
    "uniformDistributionForBN"
})
@Added((org.dmg.pmml.Version.PMML_4_3))
@JsonPropertyOrder({
    "extensions",
    "triangularDistributionForBN",
    "normalDistributionForBN",
    "lognormalDistributionForBN",
    "uniformDistributionForBN"
})
public class ContinuousDistribution
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<ContinuousDistribution>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "TriangularDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("TriangularDistributionForBN")
    private TriangularDistribution triangularDistributionForBN;
    @XmlElement(name = "NormalDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("NormalDistributionForBN")
    private NormalDistribution normalDistributionForBN;
    @XmlElement(name = "LognormalDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("LognormalDistributionForBN")
    private LognormalDistribution lognormalDistributionForBN;
    @XmlElement(name = "UniformDistributionForBN", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("UniformDistributionForBN")
    private UniformDistribution uniformDistributionForBN;
    private final static long serialVersionUID = 67371269L;

    public ContinuousDistribution() {
    }

    @ValueConstructor
    public ContinuousDistribution(
        @org.jpmml.model.annotations.Property("triangularDistributionForBN")
        TriangularDistribution triangularDistributionForBN,
        @org.jpmml.model.annotations.Property("normalDistributionForBN")
        NormalDistribution normalDistributionForBN,
        @org.jpmml.model.annotations.Property("lognormalDistributionForBN")
        LognormalDistribution lognormalDistributionForBN,
        @org.jpmml.model.annotations.Property("uniformDistributionForBN")
        UniformDistribution uniformDistributionForBN) {
        this.triangularDistributionForBN = triangularDistributionForBN;
        this.normalDistributionForBN = normalDistributionForBN;
        this.lognormalDistributionForBN = lognormalDistributionForBN;
        this.uniformDistributionForBN = uniformDistributionForBN;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public ContinuousDistribution addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public TriangularDistribution getTriangularDistributionForBN() {
        return triangularDistributionForBN;
    }

    public ContinuousDistribution setTriangularDistributionForBN(
        @org.jpmml.model.annotations.Property("triangularDistributionForBN")
        TriangularDistribution triangularDistributionForBN) {
        this.triangularDistributionForBN = triangularDistributionForBN;
        return this;
    }

    public NormalDistribution getNormalDistributionForBN() {
        return normalDistributionForBN;
    }

    public ContinuousDistribution setNormalDistributionForBN(
        @org.jpmml.model.annotations.Property("normalDistributionForBN")
        NormalDistribution normalDistributionForBN) {
        this.normalDistributionForBN = normalDistributionForBN;
        return this;
    }

    public LognormalDistribution getLognormalDistributionForBN() {
        return lognormalDistributionForBN;
    }

    public ContinuousDistribution setLognormalDistributionForBN(
        @org.jpmml.model.annotations.Property("lognormalDistributionForBN")
        LognormalDistribution lognormalDistributionForBN) {
        this.lognormalDistributionForBN = lognormalDistributionForBN;
        return this;
    }

    public UniformDistribution getUniformDistributionForBN() {
        return uniformDistributionForBN;
    }

    public ContinuousDistribution setUniformDistributionForBN(
        @org.jpmml.model.annotations.Property("uniformDistributionForBN")
        UniformDistribution uniformDistributionForBN) {
        this.uniformDistributionForBN = uniformDistributionForBN;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTriangularDistributionForBN(), getNormalDistributionForBN(), getLognormalDistributionForBN(), getUniformDistributionForBN());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
